summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/KTmpStatusMsg.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-01 15:05:43 -0600
committerTimothy Pearson <[email protected]>2013-02-01 15:05:43 -0600
commitfb3718a55f355cd22f9eb9fa4e89cd3b84b8c9ca (patch)
tree5785d2ccbdfbe2f44d02fec75b4a51f5079a4b62 /src/gui/kdeext/KTmpStatusMsg.h
parentacf699af8244896500e654cccdc8aae7e5b545db (diff)
downloadrosegarden-fb3718a55f355cd22f9eb9fa4e89cd3b84b8c9ca.tar.gz
rosegarden-fb3718a55f355cd22f9eb9fa4e89cd3b84b8c9ca.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/gui/kdeext/KTmpStatusMsg.h')
-rw-r--r--src/gui/kdeext/KTmpStatusMsg.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gui/kdeext/KTmpStatusMsg.h b/src/gui/kdeext/KTmpStatusMsg.h
index 35e1adb..45c8bb2 100644
--- a/src/gui/kdeext/KTmpStatusMsg.h
+++ b/src/gui/kdeext/KTmpStatusMsg.h
@@ -22,10 +22,10 @@
#ifndef KTMPSTATUSMSG_H
#define KTMPSTATUSMSG_H
-class KMainWindow;
+class TDEMainWindow;
/**
* A class to create a temporary message on KMainWindow's status bar
*
* Use as follows :
* { // some block of code starts here
@@ -42,10 +42,10 @@ public:
/**
* Creates a new temporary status message on the status bar
* of the specified KMainWindow.
* The id of the text widget in the status bar can be specified
*/
- KTmpStatusMsg(const TQString& msg, KMainWindow*, int id = m_defaultId);
+ KTmpStatusMsg(const TQString& msg, TDEMainWindow*, int id = m_defaultId);
~KTmpStatusMsg();
@@ -77,7 +77,7 @@ protected:
//--------------- Data members ---------------------------------
- KMainWindow* m_mainWindow;
+ TDEMainWindow* m_mainWindow;
int m_id;
static int m_defaultId;
@@ -22,10 +22,10 @@
/**
- * A class to create a temporary message on KMainWindow's status bar
+ * A class to create a temporary message on TDEMainWindow's status bar
*
* Use as follows :
@@ -42,10 +42,10 @@ public:
/**
* Creates a new temporary status message on the status bar
- * of the specified KMainWindow.
+ * of the specified TDEMainWindow.
* The id of the text widget in the status bar can be specified
*/